@@ -3,5 +3,5 @@ mod primes;
 mod vm;
 
 pub use parser::parse_function;
-pub use primes::{Calx, CalxFrame, CalxFunc};
+pub use primes::{Calx, CalxError, CalxFrame, CalxFunc};
 pub use vm::{CalxImportsDict, CalxVM};
